import { Message } from '@phosphor/messaging';
import { IIterator } from '@phosphor/algorithm';
import { Widget, Layout, LayoutItem } from '@phosphor/widgets';
export interface GenericItem {
    dispose(): void;
    fit(): void;
    update(x?: number, y?: number, width?: number, height?: number): void;
    widget: Widget;
    parentNode?: HTMLElement;
    minWidth: number;
    maxWidth: number;
    minHeight: number;
    maxHeight: number;
}
export interface SimpleBox {
    x: number;
    y: number;
    innerWidth: number;
    innerHeight: number;
    outerWidth: number;
    outerHeight: number;
}
export declare class SimpleItem implements GenericItem {
    widget: Widget;
    parentNode: HTMLElement | undefined;
    constructor(widget: Widget, parentNode?: HTMLElement | undefined);
    dispose(): void;
    fit(): void;
    update(x?: number, y?: number, width?: number, height?: number): void;
    width: number;
    height: number;
    minWidth: number;
    maxWidth: number;
    minHeight: number;
    maxHeight: number;
}
export declare class SimpleLayout<Item extends GenericItem = LayoutItem> extends Layout {
    protected Item: new (widget: Widget) => Item;
    constructor(Item?: new (widget: Widget) => Item);
    iter(): IIterator<Widget>;
    init(): void;
    dispose(): void;
    afterUpdate(handler: () => void): void;
    addItem(item: Item): any;
    addWidget(widget: Widget): Item | undefined;
    removeWidget(widget: Widget): void;
    protected attachWidget(widget: Widget): Item | undefined;
    protected detachWidget(widget: Widget): void;
    protected onBeforeAttach(msg: Message): void;
    protected onFitRequest(msg: Message): void;
    protected onUpdateRequest(msg: Message): void;
    protected onResize(msg: Widget.ResizeMessage): void;
    updateBox(width?: number, height?: number): void;
    update(width?: number, height?: number): void;
    onUpdate(): void;
    updateItem(item: Item, x: number, y: number, width: number, height: number): void;
    protected box: SimpleBox;
    protected widgetList: Widget[];
    protected itemMap: Map<Widget, Item>;
    private afterUpdateList;
    protected isUpdated: boolean;
}
